developerscripttools.BuildApiScript
===================================

.. inheritance-diagram:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript
   :private-bases:

.. autoclass:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.alias

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.formatted_help

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.formatted_usage

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.formatted_version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.long_description

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.program_name

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.scripting_group

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.short_description

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.version

Methods
-------

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.process_args

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.setup_argument_parser

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__call__

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
